@@ -53,6 +53,9 @@ myst_enable_extensions = [
 
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3", None),
+    "array-api": ("https://data-apis.org/array-api/draft", None),
+    "dask": ("https://docs.dask.org/en/stable", None),
+    "numpy": ("https://numpy.org/doc/stable", None),
     "jax": ("https://jax.readthedocs.io/en/latest", None),
 }
 
